@@ -5,15 +5,15 @@ PATH = os.path.join(os.path.dirname(__file__), 'icons.yml')
 
 def get_icon_choices():
 
-    CHOICES = []
+    CHOICES = [('', '----------')]
 
     with open(PATH) as f:
         icons = yaml.load(f)
 
-        for icon in icons.get('icons'):
-            CHOICES.append((
-                icon.get('id'),
-                icon.get('name')
-            ))
+    for icon in icons.get('icons'):
+        CHOICES.append((
+            icon.get('id'),
+            icon.get('name')
+        ))
 
     return CHOICES
\ No newline at end of file
